@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;
 our @ISA = qw(Lemonldap::NG::Portal::_SAML);
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.2.3';
 
 ## @method void issuerDBInit()
 # Load and check SAML configuration
@@ -1429,6 +1429,14 @@ sub issuerForAuthUser {
                 $nameIDContent = $self->getMetaDataURL( "samlEntityID", 0, 1 );
             }
 
+            # Manage Transient NameID format
+            if ( $nameIDFormat eq $self->getNameIDFormat("transient") ) {
+                eval {
+                    my @assert = $login->response->Assertion;
+                    $nameIDContent = $assert[0]->Subject->NameID->content;
+                };
+            }
+
             if ( $login->nameIdentifier ) {
                 $login->nameIdentifier->Format($nameIDFormat);
                 $login->nameIdentifier->content($nameIDContent)
@@ -1620,7 +1628,7 @@ sub issuerForAuthUser {
             # log that a SAML authn response is build
             my $user = $self->{sessionInfo}->{ $self->{whatToTrace} };
             my $nameIDLog;
-            foreach my $format qw(persistent transient) {
+            foreach my $format (qw(persistent transient)) {
                 if ( $login->nameIdentifier->Format eq
                     $self->getNameIDFormat($format) )
                 {
@@ -2116,14 +2124,53 @@ L<Lemonldap::NG::Portal>
 
 =head1 AUTHOR
 
-Clément Oudot, E<lt>coudot@linagora.comE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
+
+=head1 BUG REPORT
+
+Use OW2 system to report bug or ask for features:
+L<http://jira.ow2.org>
+
+=head1 DOWNLOAD
+
+Lemonldap::NG is available at
+L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, 2010 by Clément Oudot
+=over
+
+=item Copyright (C) 2009, 2010, 2012 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2009, 2010, 2011, 2012, 2013 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Copyright (C) 2010 by Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
