@@ -12,7 +12,7 @@ use strict;
 
 our @EXPORT = qw(dbh);
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.2.3';
 
 ## @method protected Lemonldap::NG::Portal::_DBI dbh(string dbiChain, string dbiUser, string dbiPassword)
 # Create connection to database
@@ -100,7 +100,7 @@ sub check_password {
         return 1;
     }
     else {
-        $self->lmLog( "Bad password for $user", 'error' );
+        $self->_sub( 'userError', "Bad password for $user" );
         return 0;
     }
 
